==> igniteui-react-charts-19.0.0.tgz: package/esm5/lib/CategoryChartToolbarProvider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { DomainChartToolbarProvider } from "./DomainChartToolbarProvider";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var CategoryChartToolbarProvider = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CategoryChartToolbarProvider, _super);
    function CategoryChartToolbarProvider() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.ah = null;
        return _this;
    }
    CategoryChartToolbarProvider.prototype.j = function (a, b) {
        var c = a;
        switch (b.name) {
            case "ShowGridlines":
                {
                    var d = b;
                    d.isChecked = c.agy != null;
                }
                break;
        }
    };
    CategoryChartToolbarProvider.prototype.ac = function (a, b, c, d) {
        var e = a;
        switch (b) {
            case "XAxisMajorStroke":
                this.k("ShowGridlines", 2, a.agy != null);
                break;
        }
    };
    CategoryChartToolbarProvider.prototype.s = function (a, b) {
        var c = a;
        if (this.h(b, "ShowGridlines")) {
            if (c.agy == null) {
                if (this.ah != null) {
                    c.agy = this.ah;
                }
                else {
                    c.agy = c.dataChart.aa5;
                }
            }
        }
        else {
            if (c.agy != null) {
                this.ah = c.agy;
                c.agy = null;
            }
        }
    };
    CategoryChartToolbarProvider.$t = markType(CategoryChartToolbarProvider, 'CategoryChartToolbarProvider', DomainChartToolbarProvider.$);
    return CategoryChartToolbarProvider;
}(DomainChartToolbarProvider));
export { CategoryChartToolbarProvider };

==> igniteui-react-charts-19.0.1.tgz: package/esm5/lib/CategoryChartToolbarProvider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { DomainChartToolbarProvider } from "./DomainChartToolbarProvider";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var CategoryChartToolbarProvider = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CategoryChartToolbarProvider, _super);
    function CategoryChartToolbarProvider() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.ah = null;
        return _this;
    }
    CategoryChartToolbarProvider.prototype.j = function (a, b) {
        var c = a;
        switch (b.name) {
            case "ShowGridlines":
                {
                    var d = b;
                    d.isChecked = c.ahg != null;
                }
                break;
        }
    };
    CategoryChartToolbarProvider.prototype.ac = function (a, b, c, d) {
        var e = a;
        switch (b) {
            case "XAxisMajorStroke":
                this.k("ShowGridlines", 2, a.ahg != null);
                break;
        }
    };
    CategoryChartToolbarProvider.prototype.s = function (a, b) {
        var c = a;
        if (this.h(b, "ShowGridlines")) {
            if (c.ahg == null) {
                if (this.ah != null) {
                    c.ahg = this.ah;
                }
                else {
                    c.ahg = c.dataChart.abh;
                }
            }
        }
        else {
            if (c.ahg != null) {
                this.ah = c.ahg;
                c.ahg = null;
            }
        }
    };
    CategoryChartToolbarProvider.$t = markType(CategoryChartToolbarProvider, 'CategoryChartToolbarProvider', DomainChartToolbarProvider.$);
    return CategoryChartToolbarProvider;
}(DomainChartToolbarProvider));
export { CategoryChartToolbarProvider };
